==> vtiger-4.0p1_1.tbz: www/vtiger/modules/System/includes/lang/ko.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: ko.php,v 1.1 2005/03/14 07:42:10 shankarr Exp $
// Translated by Sungkook KIM - ace@aceteam.org

$charset                = 'euc-kr';

$text['title']          = 'ý ';

$text['vitals']         = ' ý Ȳ';
$text['hostname']       = 'ý ȣƮ';
$text['ip']             = 'ý IP ּ';
$text['kversion']       = 'Ŀ ';
$text['dversion']       = 'Distro Name';
$text['uptime']         = ' ð';
$text['users']          = '  ';
$text['loadavg']        = ' ε';

$text['hardware']       = 'ϵ ';
$text['numcpu']         = 'μ ';
$text['cpumodel']       = 'μ ';
$text['mhz']            = 'Ĩ Ŭ';
$text['cache']          = 'ɽ ';
$text['bogomips']       = 'ü׽Ʈ Ŭ';
$text['pci']            = 'PCI ġ';
$text['ide']            = 'IDE ġ';
$text['scsi']           = 'SCSI ġ';

$text['netusage']       = ' Ʈũ ';
$text['device']         = 'ġ';
$text['received']       = ' ';
$text['sent']           = ' ';
$text['errors']         = ' / ';

$text['memusage']       = '޸ 뷮';
$text['phymem']         = ' ޸';
$text['swap']           = ' ũ';

$text['fs']             = 'Ʈ Ȳ';
$text['mount']          = 'Ʈ';
$text['partition']      = 'Ƽ';

$text['percent']        = ' ۼƮ';
$text['type']           = 'Ÿ';
$text['free']           = '';
$text['used']           = '뷮';
$text['size']           = ' 뷮';
$text['totals']         = 'հ';

$text['kb']             = 'ųιƮ(KB)';
$text['mb']             = 'ްƮ(MB)';
$text['gb']             = 'ⰡƮ(GB)';

$text['none']           = '';

$text['capacity']       = '뷮';

$text['template']       = 'ø';
$text['language']       = '';
$text['submit']         = '';
$text['created']        = '';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %r';

$text['days']           = '';
$text['hours']          = '';
$text['minutes']        = '';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>

==> vtiger-4.2.4.tbz: www/vtiger/modules/System/includes/lang/ko.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: ko.php,v 1.10 2004/08/30 15:51:26 webbie Exp $
// Translated by Sungkook KIM - ace@aceteam.org

$charset                = 'euc-kr';

$text['title']          = 'ý ';

$text['vitals']         = ' ý Ȳ';
$text['hostname']       = 'ý ȣƮ';
$text['ip']             = 'ý IP ּ';
$text['kversion']       = 'Ŀ ';
$text['dversion']       = 'Distro Name';
$text['uptime']         = ' ð';
$text['users']          = '  ';
$text['loadavg']        = ' ε';

$text['hardware']       = 'ϵ ';
$text['numcpu']         = 'μ ';
$text['cpumodel']       = 'μ ';
$text['cpuspeed']       = 'Ĩ Ŭ';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'ɽ ';
$text['bogomips']       = 'ü׽Ʈ Ŭ';

$text['pci']            = 'PCI ġ';
$text['ide']            = 'IDE ġ';
$text['scsi']           = 'SCSI ġ';
$text['usb']            = 'USB ġ';

$text['netusage']       = ' Ʈũ ';
$text['device']         = 'ġ';
$text['received']       = ' ';
$text['sent']           = ' ';
$text['errors']         = ' / ';

$text['memusage']       = '޸ 뷮';
$text['phymem']         = ' ޸';
$text['swap']           = ' ũ';

$text['fs']             = 'Ʈ Ȳ';
$text['mount']          = 'Ʈ';
$text['partition']      = 'Ƽ';

$text['percent']        = ' ۼƮ';
$text['type']           = 'Ÿ';
$text['free']           = '';
$text['used']           = '뷮';
$text['size']           = ' 뷮';
$text['totals']         = 'հ';

$text['kb']             = 'ųιƮ(KB)';
$text['mb']             = 'ްƮ(MB)';
$text['gb']             = 'ⰡƮ(GB)';

$text['none']           = '';

$text['capacity']       = '뷮';

$text['template']       = 'ø';
$text['language']       = '';
$text['submit']         = '';
$text['created']        = '';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %r';

$text['days']           = '';
$text['hours']          = '';
$text['minutes']        = '';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>
